@@ -195,7 +195,7 @@ B<Usage:>
 
 sub set{
 
-	$self = shift;
+	my $self = shift;
 
 	my ($pdl) = @_;
 
@@ -344,7 +344,7 @@ $H5T_STRING = PDL::IO::HDF5::H5T_STRING();  #HDF5 string type
 
 sub get{
 
-	$self = shift;
+	my $self = shift;
 
 	my $pdl;
 
@@ -457,7 +457,14 @@ sub get{
 	foreach (@pdldims){ $nelems *= $_; }; # calculate the number of elements
 
 	my $datasize = $nelems * PDL::howbig($pdl->get_datatype);
-	my $data = pack("x$datasize"); # create empty space for the data
+	
+	# Create empty space for the data
+	#   Incrementally, to get around problem on win32
+	my $howBig = PDL::howbig($pdl->get_datatype);
+	my $data = ' ' x $howBig;
+	foreach my $dim(@pdldims){
+		$data = $data x $dim;
+	}
 
 	# Read the data:
         $rc = PDL::IO::HDF5::H5Dread($datasetID, $internalhdf5_type, PDL::IO::HDF5::H5S_ALL(), PDL::IO::HDF5::H5S_ALL(), 
@@ -504,7 +511,7 @@ B<Usage:>
 
 sub dims{
 
-	$self = shift;
+	my $self = shift;
 
 	my $parent = $self->{parent};
 	my $groupID = $parent->IDget;
